#
# spec file for package Bear
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Tests are resolvable only on Tumbleweed
%if 0%{?suse_version} > 1500
%bcond_without tests
%else
%bcond_with tests
%endif
Name:           Bear
Version:        2.4.2
Release:        bp155.1.6
Summary:        Tool to generate compilation database for clang tooling
License:        GPL-3.0-or-later
URL:            https://github.com/rizsotto/Bear
Source:         %{URL}/archive/%{version}.tar.gz
BuildRequires:  bash-completion
BuildRequires:  cmake
%if %{with tests}
BuildRequires:  clang
BuildRequires:  gcc-c++
BuildRequires:  python3-lit
BuildRequires:  python3-setuptools
%endif

%description
Bear is a tool to generate compilation database for clang tooling.

One way to get compilation database is to use cmake as build tool. When the
project compiles with no cmake, but another build system, there is no free json
file. Bear is a tool to generate such file during the build process.

%prep
%autosetup

%build
%cmake \
    -DCMAKE_INSTALL_LIBDIR:PATH=%{_lib}
%cmake_build

%install
%cmake_install
sed -i "s|env python.*$|python3|g" %{buildroot}%{_bindir}/bear
rm -rf %{buildroot}%{_datadir}/doc/bear

%if %{with tests}
%check
pushd build
make check
popd
%endif

%files
%license COPYING
%doc ChangeLog.md README.md
%{_bindir}/bear
%{_datadir}/bash-completion/completions/bear
%{_mandir}/man1/bear.1%{?ext_man}
%dir %{_libdir}/bear
%{_libdir}/bear/libear.so

%changelog
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Fri Sep 27 2019 Martin Pluskal <mpluskal@suse.com>
- Small package modernization
* Fri Sep 27 2019 Dan Čermák <dcermak@suse.com>
- Fix sed call to fixup bear's shebang
* Fri Sep 20 2019 Dan Čermák <dcermak@suse.com>
- Packaging changes:
  - Drop unnecessary BuildRequires libconfig-devel and pkgconfig
  - Drop Bear-rpmlintrc: it contains a no longer required filter
  - Run the testsuite in %%check
  - Add bash completion files
  - Use python3 as the interpreter for /usr/bin/bear
- Update to 2.4.2
  Features:
  - Support output field in the output. (#254, @bofeng17)
  - Support Fortran compiler (#201, #241, #253, @rubyzhou2014, @chunhualiao)
  - Support filter options (#261, #252, @liugang)
  Bugfixes:
  - Fix Cpack problem to create RPM. (#191, @antmak, @reverendhomer)
- Update to 2.4.1
  - Minor bug fixes.
- Update to 2.4.0
  - Improve reliability by replacing flaky character conversion code in critical
    execution path.
* Sat Nov 17 2018 Adam Mizerski <adam@mizerski.pl>
- fix libear path
* Sat Sep 22 2018 Martin Liška <mliska@suse.cz>
- Update to 2.3.12.
* Sat Feb 25 2017 adam@mizerski.pl
- Update to 2.2.1
  - Fix spelling mistakes in man page (@sebastinas, #128)
  - Fix support multiple compilers (@handrake0724, #136)
  - Finish writing output when the build was interupted by user.
  - Travis-CI runs build against OSX machines
- Changes for 2.2.0
  - Fix spelling mistakes in README file (@sebastinas, #116)
  - Fix shell escaping to work with arguments which has space (@timangus, #124)
- Changes for 2.1.5
  - Stop filtering out `-m` options (@joshtriplett, #115)
  - Updated man page bugs section (#114)
- Changes for 2.1.4
  - Make paths to sources and include files absolute. (@svenpanne, #111)
  - Extend known issues section of documentation (#112, #108, #105, #102)
* Sat Jan 16 2016 mpluskal@suse.com
- Update to 2.1.3
  * warnings are not filtered from output
  * support universal binaries (32 and 64) on x86 OS X
- Changes for 2.1.2
  * Fix escaping quotes for shell too.
- Changes for 2.1.1
  * Fix iterator next method usage
* Wed Aug 26 2015 mpluskal@suse.com
- Update to 2.1.0
- Use cmake macros
- Use url for source
* Tue Feb 11 2014 cbosdonnat@suse.com
- Created package for Bear 1.4
